=== modified file 'NEWS'
--- NEWS	2009-11-08 03:00:11 +0000
+++ NEWS	2009-11-11 06:50:40 +0000
@@ -36,6 +36,9 @@
   allow those because XML store silently translate it anyway. (The parser
   auto-translates \r\n => \n in ways that are hard for us to catch.)
 
+* Show correct branch and repository format descriptions in 
+  ``bzr info -v`` on a smart server location.  (Andrew Bennetts, #196080)
+
 * The fix for bug #186920 accidentally broke compatibility with python
   2.4.  (Vincent Ladeuil, #475585)
 

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2009-09-24 09:45:23 +0000
+++ bzrlib/bzrdir.py	2009-11-11 06:50:40 +0000
@@ -3111,6 +3111,9 @@
         self._network_name = None
 
     def get_format_description(self):
+        if self._network_name:
+            real_format = network_format_registry.get(self._network_name)
+            return 'Remote:' + real_format.get_format_description()
         return 'bzr remote bzrdir'
 
     def get_format_string(self):

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2009-11-07 22:10:37 +0000
+++ bzrlib/remote.py	2009-11-11 06:50:40 +0000
@@ -601,7 +601,8 @@
         return self._custom_format._fetch_reconcile
 
     def get_format_description(self):
-        return 'bzr remote repository'
+        self._ensure_real()
+        return 'Remote: ' + self._custom_format.get_format_description()
 
     def __eq__(self, other):
         return self.__class__ is other.__class__
@@ -1999,7 +2000,8 @@
                 self._network_name)
 
     def get_format_description(self):
-        return 'Remote BZR Branch'
+        self._ensure_real()
+        return 'Remote: ' + self._custom_format.get_format_description()
 
     def network_name(self):
         return self._network_name

=== modified file 'bzrlib/tests/test_remote.py'
--- bzrlib/tests/test_remote.py	2009-10-15 04:01:26 +0000
+++ bzrlib/tests/test_remote.py	2009-11-11 06:50:40 +0000
@@ -27,6 +27,7 @@
 from cStringIO import StringIO
 
 from bzrlib import (
+    branch,
     bzrdir,
     config,
     errors,
@@ -36,7 +37,6 @@
     pack,
     remote,
     repository,
-    smart,
     tests,
     treebuilder,
     urlutils,
@@ -61,9 +61,8 @@
     condition_isinstance,
     split_suite_by_condition,
     multiply_tests,
-    KnownFailure,
     )
-from bzrlib.transport import get_transport, http
+from bzrlib.transport import get_transport
 from bzrlib.transport.memory import MemoryTransport
 from bzrlib.transport.remote import (
     RemoteTransport,
@@ -1782,6 +1781,20 @@
         return repo, client
 
 
+def remoted_description(format):
+    return 'Remote: ' + format.get_format_description()
+
+
+class TestBranchFormat(tests.TestCase):
+
+    def test_get_format_description(self):
+        remote_format = RemoteBranchFormat()
+        real_format = branch.BranchFormat.get_default_format()
+        remote_format._network_name = real_format.network_name()
+        self.assertEqual(remoted_description(real_format),
+            remote_format.get_format_description())
+
+
 class TestRepositoryFormat(TestRemoteRepository):
 
     def test_fast_delta(self):
@@ -1794,6 +1807,13 @@
         false_format._network_name = false_name
         self.assertEqual(False, false_format.fast_deltas)
 
+    def test_get_format_description(self):
+        remote_repo_format = RemoteRepositoryFormat()
+        real_format = repository.RepositoryFormat.get_default_format()
+        remote_repo_format._network_name = real_format.network_name()
+        self.assertEqual(remoted_description(real_format),
+            remote_repo_format.get_format_description())
+
 
 class TestRepositoryGatherStats(TestRemoteRepository):
 

